# PyPapers

## Why?

I've tried many of them and finally got fed up with [reference managements systems](https://en.wikipedia.org/wiki/Comparison_of_reference_management_software). Either too bloated with features, or lacking simplicity.

Let's try to do this the simple way: 
* all PDFs in one folder (or so) 
* a command line tool to search them 
* rely on OSx excellent `mdfind` library for searching 
* rely on excellent Preview app for reading/editing 


## Install

> still in development 